==> SuiteCRM-8.2.3.zip: public/legacy/modules/ExternalOAuthProvider/metadata/editviewdefs.php <==
<?php
/**
 *
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 *
 * SuiteCRM is an extension to SugarCRM Community Edition developed by SalesAgility Ltd.
 * Copyright (C) 2011 - 2022 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo and "Supercharged by SuiteCRM" logo. If the display of the logos is not
 * reasonably feasible for technical reasons, the Appropriate Legal Notices must
 * display the words "Powered by SugarCRM" and "Supercharged by SuiteCRM".
 */

$viewdefs['ExternalOAuthProvider'] = [
    'EditView' => [
        'templateMeta' => [
            'form' => [
                'hidden' => [
                ],
                'buttons' => [
                    'SAVE',
                    'CANCEL',
                ]
            ],
            'maxColumns' => '2',
            'widths' => [
                ['label' => '10', 'field' => '30'],
                ['label' => '10', 'field' => '30']
            ],
            'tabDefs' => [
                'DEFAULT' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
                'LBL_EXTRA' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
                'LBL_MAPPING' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
            ],
        ],
        'panels' => [
            'default' => [
                [
                    'type',
                    'connector'
                ],
                [
                    'name',
                    'scope'
                ],
                [
                    'client_id',
                    'client_secret'
                ],
                [
                    'url_authorize',
                    'url_access_token'
                ],
                [
                    'authorize_url_options',
                    ''
                ],
                [
                    'redirect_uri',
                    ''
                ],
            ],
            'lbl_extra' => [
                [
                    'extra_provider_params',
                    ''
                ],
                [
                    'get_token_request_grant',
                    'get_token_request_options'
                ],
                [
                    'refresh_token_request_grant',
                    'refresh_token_request_options'
                ],
            ],
            'lbl_mapping' => [
                [
                    'access_token_mapping',
                    'expires_in_mapping'
                ],
                [
                    'refresh_token_mapping',
                    'token_type_mapping'
                ],
            ],
        ],
    ]
];

==> SuiteCRM-8.9.2.zip: public/legacy/modules/ExternalOAuthProvider/metadata/editviewdefs.php <==
<?php
/**
 *
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 *
 * SuiteCRM is an extension to SugarCRM Community Edition developed by SalesAgility Ltd.
 * Copyright (C) 2011 - 2022 SalesAgility Ltd.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 *
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo and "Supercharged by SuiteCRM" logo. If the display of the logos is not
 * reasonably feasible for technical reasons, the Appropriate Legal Notices must
 * display the words "Powered by SugarCRM" and "Supercharged by SuiteCRM".
 */

$viewdefs['ExternalOAuthProvider'] = [
    'EditView' => [
        'templateMeta' => [
            'form' => [
                'hidden' => [
                ],
                'buttons' => [
                    'SAVE',
                    'CANCEL',
                ]
            ],
            'maxColumns' => '2',
            'widths' => [
                ['label' => '10', 'field' => '30'],
                ['label' => '10', 'field' => '30']
            ],
            'tabDefs' => [
                'DEFAULT' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
                'LBL_EXTRA' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
                'LBL_MAPPING' => [
                    'newTab' => false,
                    'panelDefault' => 'expanded',
                ],
            ],
            'javascript' => '
                <script type="text/javascript">
                    {suite_combinescripts
                        files="modules/ExternalOAuthProvider/js/fields.js,
                         modules/ExternalOAuthProvider/js/redirect_uri_toggle.js"}
                </script>
            '
        ],
        'panels' => [
            'default' => [
                [
                    'type',
                    'connector'
                ],
                [
                    'name',
                    'scope'
                ],
                [
                    'client_id',
                    'client_secret'
                ],
                [
                    'url_authorize',
                    'url_access_token'
                ],
                [
                    'authorize_url_options',
                    ''
                ],
                [
                    'redirect_uri',
                    'redirect_uri_type'
                ],
            ],
            'lbl_extra' => [
                [
                    'extra_provider_params',
                    ''
                ],
                [
                    'get_token_request_grant',
                    'get_token_request_options'
                ],
                [
                    'refresh_token_request_grant',
                    'refresh_token_request_options'
                ],
            ],
            'lbl_mapping' => [
                [
                    'access_token_mapping',
                    'expires_in_mapping'
                ],
                [
                    'refresh_token_mapping',
                    'token_type_mapping'
                ],
            ],
        ],
    ]
];
